"""AXA Python library for Python SRA and RAD clients

This module contains Python AXA library functions and protocol classes
including
  Classes:
    Client      connection to a SRA or RAD server
    Msg         generic AXA protocol message
    MsgCmd      generic AXA protocol command message
    MsgDebug    command message to set the server's tracing level
    MsgRlimit   command message to set the server's rate limit parameters
    MsgChannel  command message to turn an SRA channel on or off
    MsgWatch    command message specifying an SRA or RAD watch
    MsgAnom     command message specifying an RAD anomaly module
    MsgResult   P_OP_OK or P_OP_ERROR message from an AXA server
                    about a command
    MsgWhitNmsg AXA message containing an nmsg packet that matched an
                    SRA watch or RAD anomaly detection module
    MsgWhitIP   AXA message containing an IP packet that matched an
                    SRA watch or RAD anomaly detection module

  Exceptions:
    FatalError: fatal
    RetryError: should be retried, usually after waiting Client.again()
        milliseconds
"""

import ctypes
import sys

from axa.exceptions import *

# Wrap the real Python _axa module so that the symbols in libaxa can be used
#   elsewhere.

_ldopenflags = sys.getdlopenflags()
sys.setdlopenflags(_ldopenflags | ctypes.RTLD_GLOBAL)
from _axa import *
sys.setdlopenflags(_ldopenflags)

from axa.anomalies import *
from axa.channels import *
from axa.relay import *
from axa.server import *
from axa.watches import *
