# Copyright (c) 2015-2016 by Farsight Security, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""An SRA or RAD client that watches SIE channels using the pyaxa wrappers
for libaxa to get AXA hits."""

import axa

import re


def parse_channels(texts):
    """Convenience function to make a list of axa_p_channel_t enable or
    disable messages from a list of strings of channel names.

    Args:
      texts (list): text SIE channel aliases or "all" with optional " on"

    Returns:
      list of axa.MsgChannel messages specifying the channels
    """

    channels = []
    for channel in texts:
        m = re.match(r'(\S+)\s+(on|off)$', channel, flags=re.IGNORECASE)
        if m:
            channels.append(axa.MsgChannel(None, m.group(1),
                                           m.group(2).lower() == 'on'))
        else:
            channels.append(axa.MsgChannel(None, channel, True))
    return channels
